From 6ee5662854ac151a61def416f50cea197b53b8a1 Mon Sep 17 00:00:00 2001 From: laoyang Date: Wed, 14 Oct 2026 14:30:37 +0800 Subject: [PATCH] =?UTF-8?q?v48=EF=BC=9A=E6=97=A5=E5=8E=86=E6=9C=AC?= =?UTF-8?q?=E5=85=B1=E4=BA=AB=E9=9D=A2=E6=9D=BF=E6=8F=90=E9=80=9F=EF=BC=88?= =?UTF-8?q?=C3=97=E6=97=A5=E5=8E=86=E6=9C=AC=E6=95=B0=20=E2=86=92=20?= =?UTF-8?q?=E5=94=AF=E4=B8=80=E4=B8=80=E4=BB=BD=EF=BC=89/=20=E7=82=B9?= =?UTF-8?q?=E6=97=A5=E5=8E=86=E5=B8=A6=E5=85=A5=E5=BC=80=E5=A7=8B=E6=97=B6?= =?UTF-8?q?=E9=97=B4=E7=9C=9F=E4=BF=AE=20/=20=E5=8E=BB=E5=8D=81=E5=AD=97?= =?UTF-8?q?=E5=85=89=E6=A0=87?= MIME-Version: 1.0 Content-Type: text/plain; charset=UTF-8 Content-Transfer-Encoding: 8bit 用户 2026-10-14 三条。 ① 日历本共享弹框「特别慢」—— 真根因 = 选人组件 ×日历本数 用户原话:「设置日历本共享的时候,弹出框特别慢,好像又是 bitwarden 的问题, 需要再彻查一下。」 线上门禁诊断页实测(真实登录态): cals=12, roster=800, pp_components=12, html_kb=5876.5, json_attr_kb=1586.8, noscript_kb=4137.8, inputs=9657, labels=9593 服务端只花 ~70ms ⇒ **慢在浏览器侧**。本地夹具造出同规模复现: 首屏 4086ms / 整页 9.3MB / noscript 文本 6.7MB。 真根因:calendars.php **每本日历**都内联一整套 _person_picker,每个组件把 **全部 800 人**化成 1 份 data-pp-people JSON + 1 份